@@ -11,12 +11,14 @@ class Box(View):
         items: List[LayoutItem], *,
         direction: Literal['horizontal', 'vertical'],
         scrollbar: Union[None, bool] = None,
+        show_titles: bool = False,
         **kwargs
     ) -> None:
         super().__init__('Box', is_layout=True, **kwargs)
         self._items = items
         self._direction = direction
         self._scrollbar = scrollbar
+        self._show_titles = show_titles
     def to_dict(self) -> dict:
         ret = {
             'type': self.type,
@@ -29,6 +31,8 @@ class Box(View):
         }
         if self._scrollbar is not None:
             ret['scrollbar'] = self._scrollbar
+        if self._show_titles:
+            ret['showTitles'] = True
         return ret
     def child_views(self) -> List[View]:
         return [item.view for item in self._items]
