@@ -25,4 +25,6 @@ from .SpikeLocations import SpikeLocations, SpikeLocationsItem
 from .PositionPlot import PositionPlot
 from .ConfusionMatrix import ConfusionMatrix, UnitEventCount, MatchingUnitEventCount
 from .LiveEvaluateFunction import LiveEvaluateFunction
-from .LiveTraces import LiveTraces
\ No newline at end of file
+from .LiveTraces import LiveTraces
+from .TimeseriesGraph import TimeseriesGraph, TGDataset, TGSeries
+from .Annotations import Annotations
